@@ -1,6 +1,6 @@
 # PiTiVi , Non-linear video editor
 #
-#       ui/configure.py
+#       configure.py
 #
 # Copyright (c) 2005, Edward Hervey <bilboed@bilboed.com>
 #
@@ -24,17 +24,16 @@ Enables identical use for installed and uninstalled versions.
 """
 
 import os.path
-import string
 
-LIBDIR = '/src/lib'
-PKGDATADIR = '/src/share/pitivi'
-PIXMAPDIR = '/src/share/pixmaps'
-pitivi_version = '0.11.2'
+LIBDIR = '/usr/lib'
+PKGDATADIR = '/usr/share/pitivi'
+PIXMAPDIR = '/usr/share/pixmaps'
+pitivi_version = '0.13.0.2'
 APPNAME = 'PiTiVi'
-PYGTK_REQ = '2.8.0'
-PYGST_REQ = '0.10.6'
-GST_REQ = '0.10.13.1'
-GNONLIN_REQ = '0.10.8.1'
+PYGTK_REQ = '2.12.0'
+PYGST_REQ = '0.10.15'
+GST_REQ = '0.10.23'
+GNONLIN_REQ = '0.10.10.3'
 PYCAIRO_REQ = '1.0.0'
 
 def _get_root_dir():
@@ -48,9 +47,9 @@ def _in_devel():
 
 def get_pixmap_dir():
     """ Returns the directory for program-only pixmaps """
-    dir = os.path.dirname(os.path.abspath(__file__))
+    _dir = os.path.dirname(os.path.abspath(__file__))
     if _in_devel():
-        root = dir
+        root = _dir
     else:
         root = PKGDATADIR
     return os.path.join(root, 'pixmaps')
