@@ -25,6 +25,7 @@ Single-stream queue-less decodebin
 
 import gobject
 import gst
+from pitivi.stream import get_pad_id, pad_compatible_stream
 
 def is_raw(caps):
     """ returns True if the caps are RAW """
@@ -43,6 +44,8 @@ class SingleDecodeBin(gst.Bin):
     * Doesn't contain any internal queue
     """
 
+    QUEUE_SIZE = 1 * gst.SECOND
+
     __gsttemplates__ = (
         gst.PadTemplate ("sinkpadtemplate",
                          gst.PAD_SINK,
@@ -53,11 +56,12 @@ class SingleDecodeBin(gst.Bin):
                          gst.PAD_SOMETIMES,
                          gst.caps_new_any())
         )
-    def __init__(self, caps=None, uri=None, *args, **kwargs):
+    def __init__(self, caps=None, uri=None, stream=None, *args, **kwargs):
         gst.Bin.__init__(self, *args, **kwargs)
         if not caps:
             caps = gst.caps_new_any()
         self.caps = caps
+        self.stream = stream
         self.typefind = gst.element_factory_make("typefind", "internal-typefind")
         self.add(self.typefind)
 
@@ -83,6 +87,8 @@ class SingleDecodeBin(gst.Bin):
 
         self._factories = self._getSortedFactoryList()
 
+        self.debug("stream:%r" % self.stream)
+
 
     ## internal methods
 
@@ -157,6 +163,34 @@ class SingleDecodeBin(gst.Bin):
         for pad in to_connect:
             self._closePadLink(element, pad, pad.get_caps())
 
+    def _isDemuxer(self, element):
+        if not 'Demux' in element.get_factory().get_klass():
+            return False
+
+        potential_src_pads = 0
+        for template in element.get_pad_template_list():
+            if template.direction != gst.PAD_SRC:
+                continue
+
+            if template.presence == gst.PAD_REQUEST or \
+                    "%" in template.name_template:
+                potential_src_pads += 2
+                break
+            else:
+                potential_src_pads += 1
+
+        return potential_src_pads > 1
+
+    def _plugDecodingQueue(self, pad):
+        queue = gst.element_factory_make("queue")
+        queue.props.max_size_time = self.QUEUE_SIZE
+        self.add(queue)
+        queue.sync_state_with_parent()
+        pad.link(queue.get_pad("sink"))
+        pad = queue.get_pad("src")
+
+        return pad
+
     def _tryToLink1(self, source, pad, factories):
         """
         Tries to link one of the factories' element to the given pad.
@@ -166,6 +200,10 @@ class SingleDecodeBin(gst.Bin):
         self.debug("source:%s, pad:%s , factories:%r" % (source.get_name(),
                                                          pad.get_name(),
                                                          factories))
+
+        if self._isDemuxer(source):
+            pad = self._plugDecodingQueue(pad)
+
         result = None
         for factory in factories:
             element = factory.create()
@@ -209,10 +247,17 @@ class SingleDecodeBin(gst.Bin):
         if caps.is_any():
             self.log("type is not know yet, waiting")
             return
-        if caps.intersect(self.caps):
+
+        self.debug("stream %r" % (self.stream))
+        if caps.intersect(self.caps) and (self.stream is None or
+                (self.stream.pad_name == get_pad_id(pad))):
             # This is the desired caps
             if not self._srcpad:
                 self._wrapUp(element, pad)
+        elif is_raw(caps) and pad_compatible_stream(pad, self.stream):
+            self.log ("not the target stream, but compatible")
+            if not self._srcpad:
+                self._wrapUp(element, pad)
         elif is_raw(caps):
             self.log("We hit a raw caps which isn't the wanted one")
             # FIXME : recursively remove everything until demux/typefind
